clear all
local rootDir "/Users/~/data_jep"

use "`rootDir'/data/fig_1.dta", clear

* Data source: 2014 data obtained from the World Bank DataBank

rename CountryName country
rename SeriesName series

keep if series=="GDP per capita (current US$)" | series=="Electric power consumption (kWh per capita)"
keep country series BE
replace series="1" if series=="GDP per capita (current US$)"
replace series="2" if series=="Electric power consumption (kWh per capita)"
destring series, replace
reshape wide BE, i(country) j(series)
rename BE1 GDPpc
rename BE2 KWhpc
gen yvar=log10(GDPpc)
gen xvar=log10(KWhpc)
reg yvar xvar

*twoway (lfit yvar xvar) (scatter yvar xvar), xtitle("Electricity consumption per capita (kWh)", size(medsmall) margin(medsmall)) ytitle("GDP per capita (USD)", size(medsmall) margin(medsmall)) legend(off)

gen ind=0
replace ind=1 if	country=="United States" | country=="South Africa" | country=="India" | country=="Kenya" | ///
					country=="Brazil" | country=="Bangladesh" | country=="Ghana" | country=="Vietnam" | country=="Philippines" | country=="Nicaragua"

twoway ///
	(lfit yvar xvar, lcolor(gs13) lwidth(thin)) ///
	(scatter yvar xvar if ind==0, mfcolor(gs13) mlcolor(gs12) msymbol(circle) msize(medsmall)) ///
	(scatter yvar xvar  if ind==1, mfcolor(gs3) mlcolor(gs1) msymbol(circle) msize(medsmall) ///
	text(4.79 4.11 "United States", place(n) size(small)) ///
	text(3.25 2.65 "Nicaragua", place(s) size(small)) ///
	text(3.81 3.67 "South Africa", place(e) size(small)) ///
	text(3.20 2.96 "India", place(e) size(small)) ///
	text(3.12 2.17 "Kenya", place(w) size(small)) ///
	text(4.13 3.42 "Brazil", place(n) size(small)) ///
	text(3.0 2.51 "Bangladesh", place(s) size(small)) ///
	text(3.35 2.50 "Ghana", place(n) size(small)) ///
	text(3.31 3.2 "Vietnam", place(e) size(small)) ///
	text(3.52 2.84 "Philippines", place(n) size(small)) ///
	), ///
	xmtick( ///
	2.30 " " ///
	2.48 " " ///
	2.60 " " /// 
	2.70 " " /// 
	2.78 " " /// 
	2.85 " " /// 
	2.90 " " /// 
	2.95 " " ///
	3.30 " " ///
	3.48 " " /// 
	3.60 " " /// 
	3.70 " " /// 
	3.78 " " /// 
	3.85 " " /// 
	3.90 " " /// 
	3.95 " " /// 
	4.30 " " ///
	4.48 " " /// 
	4.60 " " /// 
	4.70 " " /// 
	4.78 " " /// 
	4.85 " " /// 
	4.90 " " /// 
	4.95 " ") ///	
	ymtick( ///
	2.30 " " ///
	2.48 " " ///
	2.60 " " /// 
	2.70 " " /// 
	2.78 " " /// 
	2.85 " " /// 
	2.90 " " /// 
	2.95 " " ///
	3.30 " " ///
	3.48 " " /// 
	3.60 " " /// 
	3.70 " " /// 
	3.78 " " /// 
	3.85 " " /// 
	3.90 " " /// 
	3.95 " " /// 
	4.30 " " ///
	4.48 " " /// 
	4.60 " " /// 
	4.70 " " /// 
	4.78 " " /// 
	4.85 " " /// 
	4.90 " " /// 
	4.95 " " ///	
	5.3 " ") ///	
	xlabel( ///
	2 "100" ///
	3 "1,000" ///
	4 "10,000" ///
	5 "100,000")  ///
	ylabel(2 "100" 3 "1,000" 4 "10,000" 5 "100,000")  ///
	xtitle("Electricity consumption per capita (kWh)", size(medsmall) margin(medsmall)) ///
	ytitle("GDP per capita (USD)", size(medsmall) margin(medsmall)) ///
	plotr(margin(7 7 1 1)) ///
	scheme(s1mono) ///
	xsize(5) ysize(3) legend(off)
graph export  "`rootDir'/fig_1/fig_1.png", replace
	
	
	
