clear all
local rootDir "/Users/~/data_jep"

local data "`rootDir'/data"
local out "`rootDir'/tab_A1_A2"

* annual average exchange rates
local xr_14 = 87.94
local xr_16 = 101.53
local xr_17 = 103.41

* annual average inflation
local i_15 = 0.0801
local i_16 = 0.0635
local i_17 = 0.0450

local x_16 = (1+`i_16')*(1+`i_15')*`xr_14'
di `x_16'
* 101.015 KES/USD
local x_17 = (1+`i_17')*(1+`i_16')*(1+`i_15')*`xr_14'
di `x_17'
* 105.561

********************************************************************************
* Appendix Tables A1, A2 - Alternative approach to assessing heterogeneity
* Last updated: 4 November 2019
********************************************************************************

********************************************************************************
* 1. Load data
********************************************************************************

use `data'/impacts_1.dta, clear
local base base_energyspending_ksh base_asset_value_ksh
local r1 gridelec_spending_ksh kerosene_spending_ksh energy_spending_ksh asset_value_ksh percapcons_ksh

foreach var in `base' {
	gen `var'_x=`var'/`xr_14'
	qui sum `var', detail
	local label : var lab `var'
	la var `var'_x "`label' (converted to USD)"
}
foreach var in `r1' {
	gen `var'_x=`var'/`x_16'
	qui sum `var', detail
	local label : var lab `var'
	la var `var'_x "`label' (converted to USD)"
}

keep reppid siteno hhid child treat_low treat_med treat_full treated_all ///
	busia base_market base_population base_connected_rate base_transearly ///
	base_connected base_housing base_bank base_energyspending_ksh_x base_female base_age base_educ base_asset_value_ksh_x ///
	female age_resp child_age child_female sibs ///
	connected gridelec_spending_ksh_x fraction_employed_all fraction_employed_f fraction_employed_m hours_worked asset_value_ksh_x percapcons_ksh_x symptoms_index life_index st_studenttest st_studenttest_avg st_studenttest_f st_studenttest_m knowledge_index ///
	electric_lighting number_appliances mobilephone radio television iron kerosene_spending_ksh_x energy_spending_ksh_x solar_shs ///
	EMI NEMI moved round metered survey

order reppid siteno hhid child treat_low treat_med treat_full treated_all ///
	busia base_market base_population base_connected_rate base_transearly ///
	base_connected base_housing base_bank base_energyspending_ksh_x base_female base_age base_educ base_asset_value_ksh_x ///
	female age_resp child_age child_female sibs ///
	connected gridelec_spending_ksh_x fraction_employed_all fraction_employed_f fraction_employed_m hours_worked asset_value_ksh_x percapcons_ksh_x symptoms_index life_index st_studenttest st_studenttest_avg st_studenttest_f st_studenttest_m knowledge_index ///
	electric_lighting number_appliances mobilephone radio television iron kerosene_spending_ksh_x energy_spending_ksh_x solar_shs ///
	EMI NEMI moved round metered survey

foreach var in base_energyspending_ksh_x base_asset_value_ksh_x gridelec_spending_ksh_x asset_value_ksh_x percapcons_ksh_x kerosene_spending_ksh_x energy_spending_ksh_x  {
   	local newname = subinstr("`var'", "_ksh_x", "",1)
   	rename `var' `newname'
}

********************************************************************************
* 2. Calculate sample shares
********************************************************************************

gen idcode=_n
gen control= (treat_low==0 & treat_med==0 & treat_full==0)
gen not_connected=1-connected

local community busia base_market base_transearly base_connected_rate base_population 
local household female age base_educ base_bank base_housing base_asset_value base_energyspending
local students base_educ base_bank base_housing base_asset_value base_energyspending child_female child_age sibs

* Calculate sample shares
reg connected treat_low treat_med treat_full if child==0

	local piat=_b[_cons]
	local pint=1-_b[treat_full]-_b[_cons]
	local pi1=_b[treat_low] 
	local pi2=_b[treat_med]-_b[treat_low]
	local pi3=_b[treat_full]-_b[treat_med]

* Adopters when the price is high
display `pi1'+`pi2'

* Adopters only when the price is low 
display `pi3'

save `data'/temp.dta, replace

********************************************************************************
* 3. Obtain LATES for each complier group for main outcomes (Table A1)
********************************************************************************

* A) All outcomes (except student outcomes)
use `data'/temp.dta, clear
drop if child==1

* Stacked regression approach, but estimating all 3 treatment effects at the same time, in order to back out LATE's for each complier group using lincom, getting analytical SE's

foreach var in electric_lighting mobilephone radio television iron solar_shs {
	replace `var'=`var'*100
}

local outcomes1 gridelec_spending electric_lighting number_appliances mobilephone radio television iron kerosene_spending energy_spending solar_shs ///
	fraction_employed_all fraction_employed_f fraction_employed_m hours_worked asset_value percapcons symptoms_index life_index knowledge_index EMI NEMI

foreach var in `outcomes1' {
eststo controls: estpost summ `var' if control==1
}

foreach var in `outcomes1' {

preserve
capture{
quietly{

eststo controls: estpost summ `var' if control==1

ivreg2 `var' (connected = treat_low) if treat_low==1 | control==1
est sto low
ivreg2 `var' (connected = treat_med) if treat_med==1 | control==1
est sto med
ivreg2 `var' (connected = treat_full) if treat_full==1 | control==1
est sto full

expand 3
bys idcode: g n=_n
tabulate n, generate(n) 
keep if (n==1&treat_low|control)|(n==2&treat_med|control)|(n==3&treat_full|control)
g connected1=connected*(n==1&(treat_low|control)) 
g connected2=connected*(n==2&(treat_med|control)) 
g connected3=connected*(n==3&(treat_full|control)) 
ivreg2 `var' (connected1 connected2 connected3=treat_low treat_med treat_full) n1 n2, cl(idcode)
eststo c1c2: lincomest ((connected1)*`pi1' + (((`pi1'+`pi2')/`pi2')*connected2 - (`pi1'/`pi2')*connected1)*`pi2')/(`pi1'+`pi2')
ivreg2 `var' (connected1 connected2 connected3=treat_low treat_med treat_full) n1 n2, cl(idcode)
eststo c3: lincomest ((`pi1'+`pi2'+`pi3')/`pi3')*connected3 - ((`pi1'+`pi2')/`pi3')*connected2
ivreg2 `var' (connected1 connected2 connected3=treat_low treat_med treat_full) n1 n2, cl(idcode)
eststo dif: lincomest (((connected1)*`pi1' + (((`pi1'+`pi2')/`pi2')*connected2 - (`pi1'/`pi2')*connected1)*`pi2')/(`pi1'+`pi2'))        -          (((`pi1'+`pi2'+`pi3')/`pi3')*connected3 - ((`pi1'+`pi2')/`pi3')*connected2)

}
}

esttab controls using `out'/tab_A1_c1`r'.tex, star(* 0.1 ** 0.05 *** 0.01) b(2) append mtitles(control p-value) varlabels((1) `var') se cells(mean(fmt(2)) sd(par))
esttab c3 c1c2 using `out'/tab_A1_c2_c3`r'.tex, star(* 0.1 ** 0.05 *** 0.01) b(2) append mtitles(LATEc3 LATEc1c2) varlabels((1) `var') se
esttab dif using `out'/tab_A1_c4`r'.tex, star(* 0.1 ** 0.05 *** 0.01) b(2) append mtitles(Dif) varlabels((1) `var') p

restore
}

* B) Student outcomes
use `data'/temp.dta, clear
keep if child==1

foreach var in electric_lighting mobilephone radio television iron solar_shs {
	replace `var'=`var'*100
}

local outcomes1 st_studenttest

foreach var in `outcomes1' {
eststo controls: estpost summ `var' if control==1
}

foreach var in `outcomes1' {

preserve
capture{
quietly{

eststo controls: estpost summ `var' if control==1

ivreg2 `var' (connected = treat_low) if treat_low==1 | control==1
est sto low
ivreg2 `var' (connected = treat_med) if treat_med==1 | control==1
est sto med
ivreg2 `var' (connected = treat_full) if treat_full==1 | control==1
est sto full

expand 3
bys idcode: g n=_n
tabulate n, generate(n) 
keep if (n==1&treat_low|control)|(n==2&treat_med|control)|(n==3&treat_full|control)
g connected1=connected*(n==1&(treat_low|control)) 
g connected2=connected*(n==2&(treat_med|control)) 
g connected3=connected*(n==3&(treat_full|control)) 
ivreg2 `var' (connected1 connected2 connected3=treat_low treat_med treat_full) n1 n2, cl(idcode)
eststo c1c2: lincomest ((connected1)*`pi1' + (((`pi1'+`pi2')/`pi2')*connected2 - (`pi1'/`pi2')*connected1)*`pi2')/(`pi1'+`pi2')
ivreg2 `var' (connected1 connected2 connected3=treat_low treat_med treat_full) n1 n2, cl(idcode)
eststo c3: lincomest ((`pi1'+`pi2'+`pi3')/`pi3')*connected3 - ((`pi1'+`pi2')/`pi3')*connected2
ivreg2 `var' (connected1 connected2 connected3=treat_low treat_med treat_full) n1 n2, cl(idcode)
eststo dif: lincomest (((connected1)*`pi1' + (((`pi1'+`pi2')/`pi2')*connected2 - (`pi1'/`pi2')*connected1)*`pi2')/(`pi1'+`pi2'))        -          (((`pi1'+`pi2'+`pi3')/`pi3')*connected3 - ((`pi1'+`pi2')/`pi3')*connected2)

}
}

esttab controls using `out'/tab_A1_c1`r'.tex, star(* 0.1 ** 0.05 *** 0.01) b(2) append mtitles(control p-value) varlabels((1) `var') se cells(mean(fmt(2)) sd(par))
esttab c3 c1c2 using `out'/tab_A1_c2_c3`r'.tex, star(* 0.1 ** 0.05 *** 0.01) b(2) append mtitles(LATEc3 LATEc1c2) varlabels((1) `var') se
esttab dif using `out'/tab_A1_c4`r'.tex, star(* 0.1 ** 0.05 *** 0.01) b(2) append mtitles(Dif) varlabels((1) `var') p

restore
}

********************************************************************************
* 4. Obtain baseline characteristics for each complier group (Table A2)
********************************************************************************

use "`data'/demand.dta", clear
sort reppid
drop if connected==1
drop connected
save `data'/temp2.dta, replace

use `data'/temp.dta, clear
keep if child==0
keep reppid control connected not_connected treat* idcode
sort reppid
merge reppid using `data'/temp2.dta
drop _merge

foreach var in female senior someschool spouse notfarmer employed awareness bank wall {
	replace `var'=`var'*100
}

local characteristics "female age senior someschool spouse notfarmer employed awareness bank earn hhsize hhyouth wall ownland distance spendl bednets sofapieces chickens radio television"

*local var "female"

foreach var in `characteristics' {

	quietly{
	
	eststo controls: estpost summ `var' if control==1
	gen int_tr_`var'=connected*`var'
	gen int_unt_`var'=not_connected*`var'

	preserve
	expand 6
	bys idcode: g n=_n
	tabulate n, generate(n) 
	keep if ((n==1|n==2)&(treat_low|control))|((n==3|n==4)&(treat_med|control))|((n==5|n==6)&(treat_full|control))
	g connected1=connected*(n==1&(treat_low|control)) 
	g not_connected1=not_connected*(n==2&(treat_low|control)) 
	g connected2=connected*(n==3&(treat_med|control))
	g not_connected2=not_connected*(n==4&(treat_med|control))
	g connected3=connected*(n==5&(treat_full|control)) 
	g not_connected3=not_connected*(n==6&(treat_full|control)) 
	gen `var'x=.
	replace `var'x=int_tr_`var' if n==1|n==3|n==5
	replace `var'x=int_unt_`var' if n==2|n==4|n==6
	gen treat_low_t=0
	replace treat_low_t=treat_low if n==1|n==3|n==5
	gen treat_med_t=0
	replace treat_med_t=treat_med if n==1|n==3|n==5
	gen treat_full_t=0
	replace treat_full_t=treat_full if n==1|n==3|n==5
	gen treat_low_u=0
	replace treat_low_u=treat_low if n==2|n==4|n==6
	gen treat_med_u=0
	replace treat_med_u=treat_med if n==2|n==4|n==6
	gen treat_full_u=0
	replace treat_full_u=treat_full if n==2|n==4|n==6
	
	ivreg2 `var'x (connected1 not_connected1 connected2 not_connected2 connected3 not_connected3=treat_low_t treat_med_t treat_full_t treat_low_u treat_med_u treat_full_u) n1 n2 n3 n4 n5, cl(idcode) partial(n1 n2 n3 n4 n5)
	eststo c1c2_t: lincomest ((connected1)*`pi1' + (((`pi1'+`pi2')/`pi2')*connected2 - (`pi1'/`pi2')*connected1)*`pi2')/(`pi1'+`pi2')
	local vmeanc1c2_t=_se[(1)]^2
	ivreg2 `var'x (connected1 not_connected1 connected2 not_connected2 connected3 not_connected3=treat_low_t treat_med_t treat_full_t treat_low_u treat_med_u treat_full_u) n1 n2 n3 n4 n5, cl(idcode) partial(n1 n2 n3 n4 n5)
	eststo c1c2_u: lincomest ((not_connected1)*`pi1' + (((`pi1'+`pi2')/`pi2')*not_connected2 - (`pi1'/`pi2')*not_connected1)*`pi2')/(`pi1'+`pi2')
	local vmeanc1c2_u=_se[(1)]^2
	ivreg2 `var'x (connected1 not_connected1 connected2 not_connected2 connected3 not_connected3=treat_low_t treat_med_t treat_full_t treat_low_u treat_med_u treat_full_u) n1 n2 n3 n4 n5, cl(idcode) partial(n1 n2 n3 n4 n5)
	eststo c1c2: lincomest ((((connected1)*`pi1' + (((`pi1'+`pi2')/`pi2')*connected2 - (`pi1'/`pi2')*connected1)*`pi2')/(`pi1'+`pi2'))/`vmeanc1c2_t' + (((not_connected1)*`pi1' + (((`pi1'+`pi2')/`pi2')*not_connected2 - (`pi1'/`pi2')*not_connected1)*`pi2')/(`pi1'+`pi2'))/`vmeanc1c2_u')/((1/`vmeanc1c2_t')+(1/`vmeanc1c2_u'))

	ivreg2 `var'x (connected1 not_connected1 connected2 not_connected2 connected3 not_connected3=treat_low_t treat_med_t treat_full_t treat_low_u treat_med_u treat_full_u) n1 n2 n3 n4 n5, cl(idcode) partial(n1 n2 n3 n4 n5)
	eststo c3_t: lincomest ((`pi1'+`pi2'+`pi3')/`pi3')*connected3 - ((`pi1'+`pi2')/`pi3')*connected2
	local vmeanc3_t=_se[(1)]^2
	ivreg2 `var'x (connected1 not_connected1 connected2 not_connected2 connected3 not_connected3=treat_low_t treat_med_t treat_full_t treat_low_u treat_med_u treat_full_u) n1 n2 n3 n4 n5, cl(idcode) partial(n1 n2 n3 n4 n5)
	eststo c3_u: lincomest ((`pi1'+`pi2'+`pi3')/`pi3')*not_connected3 - ((`pi1'+`pi2')/`pi3')*not_connected2
	local vmeanc3_u=_se[(1)]^2
	ivreg2 `var'x (connected1 not_connected1 connected2 not_connected2 connected3 not_connected3=treat_low_t treat_med_t treat_full_t treat_low_u treat_med_u treat_full_u) n1 n2 n3 n4 n5, cl(idcode) partial(n1 n2 n3 n4 n5)
	eststo c3: lincomest (((((`pi1'+`pi2'+`pi3')/`pi3')*connected3 - ((`pi1'+`pi2')/`pi3')*connected2)/`vmeanc3_t')+((((`pi1'+`pi2'+`pi3')/`pi3')*not_connected3 - ((`pi1'+`pi2')/`pi3')*not_connected2)/`vmeanc3_u'))/((1/`vmeanc3_t')+(1/`vmeanc3_u'))
	
	ivreg2 `var'x (connected1 not_connected1 connected2 not_connected2 connected3 not_connected3=treat_low_t treat_med_t treat_full_t treat_low_u treat_med_u treat_full_u) n1 n2 n3 n4 n5, cl(idcode) partial(n1 n2 n3 n4 n5)
	eststo dif: lincomest (((((connected1)*`pi1' + (((`pi1'+`pi2')/`pi2')*connected2 - (`pi1'/`pi2')*connected1)*`pi2')/(`pi1'+`pi2'))/`vmeanc1c2_t' + (((not_connected1)*`pi1' + (((`pi1'+`pi2')/`pi2')*not_connected2 - (`pi1'/`pi2')*not_connected1)*`pi2')/(`pi1'+`pi2'))/`vmeanc1c2_u')/((1/`vmeanc1c2_t')+(1/`vmeanc1c2_u')))      -       ((((((`pi1'+`pi2'+`pi3')/`pi3')*connected3 - ((`pi1'+`pi2')/`pi3')*connected2)/`vmeanc3_t')+((((`pi1'+`pi2'+`pi3')/`pi3')*not_connected3 - ((`pi1'+`pi2')/`pi3')*not_connected2)/`vmeanc3_u'))/((1/`vmeanc3_t')+(1/`vmeanc3_u')))
	}
	
	esttab c3 c1c2 using `out'/tab_A2_c1_c2`r'.tex, nostar b(2) append mtitles(c3 c1c2) varlabels((1) `var') se
	esttab dif using `out'/tab_A2_c3`r'.tex, star(* 0.1 ** 0.05 *** 0.01) b(2) append mtitles(Dif) varlabels((1) `var') p
	restore
}

rm `data'/temp.dta
rm `data'/temp2.dta

